==> estateplat-common-1.2.3-20180620.033123-124-sources.jar: cn/gtmap/estateplat/model/stockHouse/contract/FcjyClfJjhtFwgk.java <==
package cn.gtmap.estateplat.model.stockHouse.contract;

import cn.gtmap.estateplat.model.server.core.InsertVo;

import javax.persistence.Id;
import javax.persistence.Table;
import java.util.Date;

/**
 * @author <a href="mailto:lijian@gtmap.cn">lijian</a>
 * @version 1.0, 2018/1/16
 * @description 经纪合同房屋概况
 */
@Table(name = "fcjy_clf_jjht_fwgk")
public class FcjyClfJjhtFwgk implements InsertVo{
    @Id
    private String id;//id
    private String jjhtid;//经纪合同id
    private String hbh;//户编号
    private String fwzl;//房屋坐落
    private String cqzh;//产权证号
    private String fwxz;//房屋性质
    private String jcnf;//建成年份
    private Double jzmj;//建筑面积
    private String xzql;//限制权利
    private Date xzqljcqx;//限制权利解除期限
    private Date jfsj;//交付时间
    private String jfzk;//交付状况
    private String qtsm;//其他说明
    private String fwlx;//房屋性质
    private String fwjg;//房屋结构
    private String ghyt;//规划用途
    private String yfwxz;//原房屋性质
    private String yfwlx;//原房屋类型
    private String yfwjg;//原房屋结构
    private String yghyt;//原规划用途
    private String szc;//所在层
    private String zcs;//总层数

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getJjhtid() {
        return jjhtid;
    }

    public void setJjhtid(String jjhtid) {
        this.jjhtid = jjhtid;
    }

    public String getHbh() {
        return hbh;
    }

    public void setHbh(String hbh) {
        this.hbh = hbh;
    }

    public String getFwzl() {
        return fwzl;
    }

    public void setFwzl(String fwzl) {
        this.fwzl = fwzl;
    }

    public String getCqzh() {
        return cqzh;
    }

    public void setCqzh(String cqzh) {
        this.cqzh = cqzh;
    }

    public String getFwxz() {
        return fwxz;
    }

    public void setFwxz(String fwxz) {
        this.fwxz = fwxz;
    }

    public String getJcnf() {
        return jcnf;
    }

    public void setJcnf(String jcnf) {
        this.jcnf = jcnf;
    }

    public Double getJzmj() {
        return jzmj;
    }

    public void setJzmj(Double jzmj) {
        this.jzmj = jzmj;
    }

    public String getXzql() {
        return xzql;
    }

    public void setXzql(String xzql) {
        this.xzql = xzql;
    }

    public Date getXzqljcqx() {
        return xzqljcqx;
    }

    public void setXzqljcqx(Date xzqljcqx) {
        this.xzqljcqx = xzqljcqx;
    }

    public Date getJfsj() {
        return jfsj;
    }

    public void setJfsj(Date jfsj) {
        this.jfsj = jfsj;
    }

    public String getJfzk() {
        return jfzk;
    }

    public void setJfzk(String jfzk) {
        this.jfzk = jfzk;
    }

    public String getQtsm() {
        return qtsm;
    }

    public void setQtsm(String qtsm) {
        this.qtsm = qtsm;
    }

    public String getFwlx() {
        return fwlx;
    }

    public void setFwlx(String fwlx) {
        this.fwlx = fwlx;
    }

    public String getFwjg() {
        return fwjg;
    }

    public void setFwjg(String fwjg) {
        this.fwjg = fwjg;
    }

    public String getGhyt() {
        return ghyt;
    }

    public void setGhyt(String ghyt) {
        this.ghyt = ghyt;
    }

    public String getYfwxz() {
        return yfwxz;
    }

    public void setYfwxz(String yfwxz) {
        this.yfwxz = yfwxz;
    }

    public String getYfwlx() {
        return yfwlx;
    }

    public void setYfwlx(String yfwlx) {
        this.yfwlx = yfwlx;
    }

    public String getYfwjg() {
        return yfwjg;
    }

    public void setYfwjg(String yfwjg) {
        this.yfwjg = yfwjg;
    }

    public String getYghyt() {
        return yghyt;
    }

    public void setYghyt(String yghyt) {
        this.yghyt = yghyt;
    }

    public String getSzc() {
        return szc;
    }

    public void setSzc(String szc) {
        this.szc = szc;
    }

    public String getZcs() {
        return zcs;
    }

    public void setZcs(String zcs) {
        this.zcs = zcs;
    }
}

==> estateplat-common-1.2.4-20210726.070818-827-sources.jar: cn/gtmap/estateplat/model/stockHouse/contract/FcjyClfJjhtFwgk.java <==
package cn.gtmap.estateplat.model.stockHouse.contract;

import cn.gtmap.estateplat.model.server.core.InsertVo;

import javax.persistence.Id;
import javax.persistence.Table;
import java.util.Date;

/**
 * @author <a href="mailto:lijian@gtmap.cn">lijian</a>
 * @version 1.0, 2018/1/16
 * @description 经纪合同房屋概况
 */
@Table(name = "fcjy_clf_jjht_fwgk")
public class FcjyClfJjhtFwgk implements InsertVo{
    @Id
    private String id;//id
    private String jjhtid;//经纪合同id
    private String hbh;//户编号
    private String fwzl;//房屋坐落
    private String cqzh;//产权证号
    private String fwxz;//房屋性质
    private String jcnf;//建成年份
    private Double jzmj;//建筑面积
    private String xzql;//限制权利
    private Date xzqljcqx;//限制权利解除期限
    private Date jfsj;//交付时间
    private String jfzk;//交付状况
    private String qtsm;//其他说明
    private String fwlx;//房屋性质
    private String fwjg;//房屋结构
    private String ghyt;//规划用途
    private String yfwxz;//原房屋性质
    private String yfwlx;//原房屋类型
    private String yfwjg;//原房屋结构
    private String yghyt;//原规划用途
    private String szc;//所在层
    private String zcs;//总层数
    private String tdsyqr;//土地使用权人
    private String tdsyqzh;//土地使用权证号
    private String tdsyqlx;//土地使用权类型
    private Double fttdmj;//分摊土地面积
    private Double dytdmj;//独用土地面积
    private Double zdmj;//土地使用权面积

    public String getTdsyqr() {
        return tdsyqr;
    }

    public void setTdsyqr(String tdsyqr) {
        this.tdsyqr = tdsyqr;
    }

    public String getTdsyqzh() {
        return tdsyqzh;
    }

    public void setTdsyqzh(String tdsyqzh) {
        this.tdsyqzh = tdsyqzh;
    }

    public String getTdsyqlx() {
        return tdsyqlx;
    }

    public void setTdsyqlx(String tdsyqlx) {
        this.tdsyqlx = tdsyqlx;
    }

    public Double getFttdmj() {
        return fttdmj;
    }

    public void setFttdmj(Double fttdmj) {
        this.fttdmj = fttdmj;
    }

    public Double getDytdmj() {
        return dytdmj;
    }

    public void setDytdmj(Double dytdmj) {
        this.dytdmj = dytdmj;
    }

    public Double getZdmj() {
        return zdmj;
    }

    public void setZdmj(Double zdmj) {
        this.zdmj = zdmj;
    }

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getJjhtid() {
        return jjhtid;
    }

    public void setJjhtid(String jjhtid) {
        this.jjhtid = jjhtid;
    }

    public String getHbh() {
        return hbh;
    }

    public void setHbh(String hbh) {
        this.hbh = hbh;
    }

    public String getFwzl() {
        return fwzl;
    }

    public void setFwzl(String fwzl) {
        this.fwzl = fwzl;
    }

    public String getCqzh() {
        return cqzh;
    }

    public void setCqzh(String cqzh) {
        this.cqzh = cqzh;
    }

    public String getFwxz() {
        return fwxz;
    }

    public void setFwxz(String fwxz) {
        this.fwxz = fwxz;
    }

    public String getJcnf() {
        return jcnf;
    }

    public void setJcnf(String jcnf) {
        this.jcnf = jcnf;
    }

    public Double getJzmj() {
        return jzmj;
    }

    public void setJzmj(Double jzmj) {
        this.jzmj = jzmj;
    }

    public String getXzql() {
        return xzql;
    }

    public void setXzql(String xzql) {
        this.xzql = xzql;
    }

    public Date getXzqljcqx() {
        return xzqljcqx;
    }

    public void setXzqljcqx(Date xzqljcqx) {
        this.xzqljcqx = xzqljcqx;
    }

    public Date getJfsj() {
        return jfsj;
    }

    public void setJfsj(Date jfsj) {
        this.jfsj = jfsj;
    }

    public String getJfzk() {
        return jfzk;
    }

    public void setJfzk(String jfzk) {
        this.jfzk = jfzk;
    }

    public String getQtsm() {
        return qtsm;
    }

    public void setQtsm(String qtsm) {
        this.qtsm = qtsm;
    }

    public String getFwlx() {
        return fwlx;
    }

    public void setFwlx(String fwlx) {
        this.fwlx = fwlx;
    }

    public String getFwjg() {
        return fwjg;
    }

    public void setFwjg(String fwjg) {
        this.fwjg = fwjg;
    }

    public String getGhyt() {
        return ghyt;
    }

    public void setGhyt(String ghyt) {
        this.ghyt = ghyt;
    }

    public String getYfwxz() {
        return yfwxz;
    }

    public void setYfwxz(String yfwxz) {
        this.yfwxz = yfwxz;
    }

    public String getYfwlx() {
        return yfwlx;
    }

    public void setYfwlx(String yfwlx) {
        this.yfwlx = yfwlx;
    }

    public String getYfwjg() {
        return yfwjg;
    }

    public void setYfwjg(String yfwjg) {
        this.yfwjg = yfwjg;
    }

    public String getYghyt() {
        return yghyt;
    }

    public void setYghyt(String yghyt) {
        this.yghyt = yghyt;
    }

    public String getSzc() {
        return szc;
    }

    public void setSzc(String szc) {
        this.szc = szc;
    }

    public String getZcs() {
        return zcs;
    }

    public void setZcs(String zcs) {
        this.zcs = zcs;
    }
}
